@@ -13,7 +13,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkGet.c 1.13 96/04/26 10:25:46
+ * RCS: @(#) $Id: tkGet.c,v 1.2 1998/09/14 18:23:11 stanton Exp $
  */
 
 #include "tkInt.h"
@@ -26,160 +26,6 @@
 
 static Tcl_HashTable uidTable;
 static int initialized = 0;
-static Tcl_ObjType *intType = NULL;
-static Tcl_ObjType *doubleType = NULL;
-
-/*
- * Prototypes for procedures defined later in this file:
- */
-
-static void		DupPixelInternalRep _ANSI_ARGS_((Tcl_Obj *srcPtr,
-			    Tcl_Obj *copyPtr));
-static int		SetPixelFromAny _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tcl_Obj *objPtr));
-static void		UpdateStringOfPixel _ANSI_ARGS_((Tcl_Obj *objPtr));
-
-static Tcl_ObjType pixelType = {
-    "pixel",				/* name */
-    (Tcl_FreeInternalRepProc *) NULL,   /* freeIntRepProc */
-    DupPixelInternalRep,		/* dupIntRepProc */
-    UpdateStringOfPixel,		/* updateStringProc */
-    SetPixelFromAny			/* setFromAnyProc */
-};
-
-/*
- *----------------------------------------------------------------------
- *
- * DupPixelInternalRep --
- *
- *	Initialize the internal representation of a pixel Tcl_Obj to a
- *	copy of the internal representation of an existing pixel object. 
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	"copyPtr"s internal rep is set to the pixel representation 
- *	corresponding to "srcPtr"s internal rep.
- *
- *----------------------------------------------------------------------
- */
-
-static void
-DupPixelInternalRep(srcPtr, copyPtr)
-    register Tcl_Obj *srcPtr;	/* Object with internal rep to copy. */
-    register Tcl_Obj *copyPtr;	/* Object with internal rep to set. */
-{
-    copyPtr->internalRep.doubleValue = srcPtr->internalRep.doubleValue;
-    copyPtr->typePtr = &pixelType;
-}
-
-/*
- *----------------------------------------------------------------------
- *
- * SetPixelFromAny --
- *
- *	Attempt to generate a pixel internal form
- *	for the Tcl object "objPtr". If the most appropriate
- *	representation is integer or double, this is used
- *	instead.
- *
- * Results:
- *	The return value is a standard Tcl object result. If an error occurs
- *	during conversion, an error message is left in the interpreter's
- *	result unless "interp" is NULL.
- *
- * Side effects:
- *	If no error occurs, a double is stored as "objPtr"s internal
- *	representation.
- *
- *----------------------------------------------------------------------
- */
-
-EXTERN int TclLooksLikeInt _ANSI_ARGS_((char *p));
-
-static int
-SetPixelFromAny(interp, objPtr)
-    Tcl_Interp *interp;		/* Used for error reporting if not NULL. */
-    register Tcl_Obj *objPtr;	/* The object to convert. */
-{
-    char *string, *end;
-    double d;
-
-    if (!intType) intType = Tcl_GetObjType("int");
-    if (objPtr->typePtr == intType) return TCL_OK;
-    if (!doubleType) doubleType = Tcl_GetObjType("double");
-    if (objPtr->typePtr == doubleType) return TCL_OK;
-    
-    string = Tcl_GetStringFromObj(objPtr, NULL);
-    d = strtod(string, &end);
-    if (end == string) {
-	error:
-	if (interp) {
-	    Tcl_AppendResult(interp, "bad screen distance \"", string,
-		    "\"", (char *) NULL);
-	}
-	return TCL_ERROR;
-    }
-    while ((*end != '\0') && isspace(UCHAR(*end))) {
-	end++;
-    }
-    switch (*end) {
-	case 0:
-	    if (TclLooksLikeInt(string)) {
-		return Tcl_ConvertToType(interp, objPtr, intType);
-	    }
-	    return Tcl_ConvertToType(interp, objPtr, doubleType);
-	case 'c':
-	    d *= 10;
-	    end++;
-	    break;
-	case 'i':
-	    d *= 25.4;
-	    end++;
-	    break;
-	case 'm':
-	    end++;
-	    break;
-	case 'p':
-	    d *= (25.4/72.0);
-	    end++;
-	    break;
-	default:
-	    goto error;
-    }
-    if ((objPtr->typePtr != NULL) && (objPtr->typePtr->freeIntRepProc != NULL)) {
-	objPtr->typePtr->freeIntRepProc(objPtr);
-    }
-
-    objPtr->internalRep.doubleValue = d;
-    objPtr->typePtr = &pixelType;
-
-    return TCL_OK;
-}
-/*
- *----------------------------------------------------------------------
- *
- * UpdateStringOfPixel --
- *
- *	Should never be called, because the string is always left valid.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	None.
- *
- *----------------------------------------------------------------------
- */
-
-static void
-UpdateStringOfPixel(objPtr)
-    register Tcl_Obj *objPtr;	/* Pixel obj with string rep to update. */
-{
-	panic("UpdateStringOfPixel should never be called");
-}
-
 
 /*
  *--------------------------------------------------------------
@@ -655,59 +501,11 @@ Tk_GetScreenMM(interp, tkwin, string, doublePtr)
     *doublePtr = d;
     return TCL_OK;
 }
-
-/*
- *--------------------------------------------------------------
- *
- * TkGetScreenMMFromObj --
- *
- *	Given a object, returns the number of screen millimeters
- *	corresponding to that string.
- *
- * Results:
- *	The return value is a standard Tcl return result.  If
- *	TCL_OK is returned, then everything went well and the
- *	screen distance is stored at *doublePtr;  otherwise
- *	TCL_ERROR is returned and an error message is left in
- *	interp->result.
- *
- * Side effects:
- *	None.
- *
- *--------------------------------------------------------------
- */
-
-int
-TkGetScreenMMFromObj(interp, tkwin, obj, doublePtr)
-    Tcl_Interp *interp;		/* Use this for error reporting. */
-    Tk_Window tkwin;		/* Window whose screen determines conversion
-				 * from centimeters and other absolute
-				 * units. */
-    Tcl_Obj *obj;		/* Object describing a screen distance. */
-    double *doublePtr;		/* Place to store converted result. */
-{
-    double d;
-    if (Tcl_ConvertToType(interp, obj, &pixelType)) {
-	return TCL_ERROR;
-    }
-    if (obj->typePtr == &pixelType) {
-	*doublePtr = obj->internalRep.doubleValue;
-	return TCL_OK;
-    } else if (obj->typePtr == intType) {
-	d = (double) obj->internalRep.longValue;
-    } else { /* must be doubleType */
-	d = obj->internalRep.doubleValue;
-    }
-
-    d *= WidthMMOfScreen(Tk_Screen(tkwin));
-    *doublePtr =  d / WidthOfScreen(Tk_Screen(tkwin));
-    return TCL_OK;
-}
 
 /*
  *--------------------------------------------------------------
  *
- * Tk_GetDoublePixels --
+ * Tk_GetPixels --
  *
  *	Given a string, returns the number of pixels corresponding
  *	to that string.
@@ -715,7 +513,7 @@ TkGetScreenMMFromObj(interp, tkwin, obj, doublePtr)
  * Results:
  *	The return value is a standard Tcl return result.  If
  *	TCL_OK is returned, then everything went well and the
- *	pixel distance is stored at *doublePtr;  otherwise
+ *	rounded pixel distance is stored at *intPtr;  otherwise
  *	TCL_ERROR is returned and an error message is left in
  *	interp->result.
  *
@@ -726,18 +524,18 @@ TkGetScreenMMFromObj(interp, tkwin, obj, doublePtr)
  */
 
 int
-Tk_GetDoublePixels(interp, tkwin, string, doublePtr)
+Tk_GetPixels(interp, tkwin, string, intPtr)
     Tcl_Interp *interp;		/* Use this for error reporting. */
     Tk_Window tkwin;		/* Window whose screen determines conversion
 				 * from centimeters and other absolute
 				 * units. */
-    CONST char *string;		/* String describing a number of pixels. */
-    double *doublePtr;		/* Place to store converted result. */
+    char *string;		/* String describing a justification style. */
+    int *intPtr;		/* Place to store converted result. */
 {
     char *end;
     double d;
 
-    d = strtod((char *) string, &end);
+    d = strtod(string, &end);
     if (end == string) {
 	error:
 	Tcl_AppendResult(interp, "bad screen distance \"", string,
@@ -779,98 +577,6 @@ Tk_GetDoublePixels(interp, tkwin, string, doublePtr)
     if (*end != 0) {
 	goto error;
     }
-    *doublePtr = d;
-    return TCL_OK;
-}
-
-/*
- *--------------------------------------------------------------
- *
- * Tk_GetPixels --
- *
- *	Given a string, returns the number of pixels corresponding
- *	to that string.
- *
- * Results:
- *	The return value is a standard Tcl return result.  If
- *	TCL_OK is returned, then everything went well and the
- *	rounded pixel distance is stored at *intPtr;  otherwise
- *	TCL_ERROR is returned and an error message is left in
- *	interp->result.
- *
- * Side effects:
- *	None.
- *
- *--------------------------------------------------------------
- */
-
-int
-Tk_GetPixels(interp, tkwin, string, intPtr)
-    Tcl_Interp *interp;		/* Use this for error reporting. */
-    Tk_Window tkwin;		/* Window whose screen determines conversion
-				 * from centimeters and other absolute
-				 * units. */
-    char *string;		/* String describing a number of pixels. */
-    int *intPtr;		/* Place to store converted result. */
-{
-    double d;
-
-    if (Tk_GetDoublePixels(interp, tkwin, string, &d) != TCL_OK) {
-	return TCL_ERROR;
-    }
-
-    if (d < 0) {
-	*intPtr = (int) (d - 0.5);
-    } else {
-	*intPtr = (int) (d + 0.5);
-    }
-    return TCL_OK;
-}
-
-/*
- *--------------------------------------------------------------
- *
- * TkGetPixelsFromObj --
- *
- *	Given a object, returns the number of pixels corresponding
- *	to that object.
- *
- * Results:
- *	The return value is a standard Tcl return result.  If
- *	TCL_OK is returned, then everything went well and the
- *	rounded pixel distance is stored at *intPtr;  otherwise
- *	TCL_ERROR is returned and an error message is left in
- *	interp->result.
- *
- * Side effects:
- *	None.
- *
- *--------------------------------------------------------------
- */
-
-int
-TkGetPixelsFromObj(interp, tkwin, obj, intPtr)
-    Tcl_Interp *interp;		/* Use this for error reporting. */
-    Tk_Window tkwin;		/* Window whose screen determines conversion
-				 * from centimeters and other absolute
-				 * units. */
-    Tcl_Obj *obj;		/* Object describing a number of pixels. */
-    int *intPtr;		/* Place to store converted result. */
-{
-    double d;
-    if (Tcl_ConvertToType(interp, obj, &pixelType)) {
-	return TCL_ERROR;
-    }
-    if (obj->typePtr == &pixelType) {
-	d = obj->internalRep.doubleValue * WidthOfScreen(Tk_Screen(tkwin));
-	d /= WidthMMOfScreen(Tk_Screen(tkwin));
-    } else if (obj->typePtr == intType) {
-	*intPtr = obj->internalRep.longValue;
-	return TCL_OK;
-    } else { /* must be doubleType */
-	d = obj->internalRep.doubleValue;
-    }
-
     if (d < 0) {
 	*intPtr = (int) (d - 0.5);
     } else {
