@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkInt.h 1.6 98/08/04 12:19:22
+ * RCS: $Id: tkInt.h,v 1.8 1998/09/30 19:01:20 rjohnson Exp $ 
  */
 
 #ifndef _TKINT
@@ -38,6 +38,7 @@
 
 typedef struct TkColormap TkColormap;
 typedef struct TkGrabEvent TkGrabEvent;
+typedef struct Tk_PostscriptInfo Tk_PostscriptInfo;
 typedef struct TkpCursor_ *TkpCursor;
 typedef struct TkRegion_ *TkRegion;
 typedef struct TkStressedCmap TkStressedCmap;
@@ -335,12 +336,6 @@ typedef struct TkDisplay {
                                  * the display when we no longer have any
                                  * Tk applications using it.
                                  */
-    int mouseButtonState;	/* current mouse button state for this
-				 * display */
-    int warpInProgress;
-    Window warpWindow;
-    int warpX;
-    int warpY;
 } TkDisplay;
 
 /*
@@ -695,7 +690,6 @@ extern TkDisplay *tkDisplayList;
  */
 
 extern Tk_Uid			tkActiveUid;
-extern Tk_SmoothMethod		tkBezierSmoothMethod;
 extern Tk_ImageType		tkBitmapImageType;
 extern Tk_Uid			tkDisabledUid;
 extern Tk_PhotoImageFormat	tkImgFmtGIF;
@@ -717,8 +711,6 @@ EXTERN char *		TkAlignImageData _ANSI_ARGS_((XImage *image,
 			    int alignment, int bitOrder));
 EXTERN TkWindow *	TkAllocWindow _ANSI_ARGS_((TkDisplay *dispPtr,
 			    int screenNum, TkWindow *parentPtr));
-EXTERN int		TkAreaToPolygon _ANSI_ARGS_((double *polyPtr,
-			    int numPoints, double *rectPtr));
 EXTERN void		TkBezierPoints _ANSI_ARGS_((double control[],
 			    int numSteps, double *coordPtr));
 EXTERN void		TkBezierScreenPoints _ANSI_ARGS_((Tk_Canvas canvas,
@@ -729,9 +721,6 @@ EXTERN void		TkBindEventProc _ANSI_ARGS_((TkWindow *winPtr,
 			    XEvent *eventPtr));
 EXTERN void		TkBindFree _ANSI_ARGS_((TkMainInfo *mainPtr));
 EXTERN void		TkBindInit _ANSI_ARGS_((TkMainInfo *mainPtr));
-EXTERN int		TkCanvasGetCoordObj _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Canvas canvas, Tcl_Obj *obj,
-			    double *doublePtr));
 EXTERN void		TkChangeEventWindow _ANSI_ARGS_((XEvent *eventPtr,
 			    TkWindow *winPtr));
 #ifndef TkClipBox
@@ -751,9 +740,6 @@ EXTERN unsigned long	TkCreateBindingProcedure _ANSI_ARGS_((
 			    ClientData object, char *eventString,
 			    TkBindEvalProc *evalProc, TkBindFreeProc *freeProc,
 			    ClientData clientData));
-EXTERN Pixmap		TkCreateBitmapFromData _ANSI_ARGS_((Display* display,
-			    Drawable d, CONST char* data,
-			    unsigned int width, unsigned int height));
 EXTERN TkCursor *	TkCreateCursorFromData _ANSI_ARGS_((Tk_Window tkwin,
 			    char *source, char *mask, int width, int height,
 			    int xHot, int yHot, XColor fg, XColor bg));
@@ -776,8 +762,6 @@ EXTERN void		TkDoConfigureNotify _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkDrawInsetFocusHighlight _ANSI_ARGS_((
 			    Tk_Window tkwin, GC gc, int width,
 			    Drawable drawable, int padding));
-EXTERN void		TkEventCleanupProc _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp));
 EXTERN void		TkEventDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkFillPolygon _ANSI_ARGS_((Tk_Canvas canvas,
 			    double *coordPtr, int numPoints, Display *display,
@@ -785,9 +769,6 @@ EXTERN void		TkFillPolygon _ANSI_ARGS_((Tk_Canvas canvas,
 EXTERN int		TkFindStateNum _ANSI_ARGS_((Tcl_Interp *interp,
 			    CONST char *option, CONST TkStateMap *mapPtr,
 			    CONST char *strKey));
-EXTERN int		TkFindStateNumObj _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tcl_Obj *optionPtr, CONST TkStateMap *mapPtr,
-			    Tcl_Obj *keyPtr));
 EXTERN char *		TkFindStateString _ANSI_ARGS_((
 			    CONST TkStateMap *mapPtr, int numKey));
 EXTERN void		TkFocusDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
@@ -823,22 +804,13 @@ EXTERN int		TkGetInterpNames _ANSI_ARGS_((Tcl_Interp *interp,
 EXTERN int		TkGetMiterPoints _ANSI_ARGS_((double p1[], double p2[],
 			    double p3[], double width, double m1[],
 			    double m2[]));
-#ifndef TkGetNativeProlog
-EXTERN int		TkGetNativeProlog _ANSI_ARGS_((Tcl_Interp *interp));
-#endif
-EXTERN int		TkGetPixelsFromObj _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Window tkwin, Tcl_Obj *obj, int *intPtr));
 EXTERN void		TkGetPointerCoords _ANSI_ARGS_((Tk_Window tkwin,
 			    int *xPtr, int *yPtr));
 EXTERN int		TkGetProlog _ANSI_ARGS_((Tcl_Interp *interp));
-EXTERN int		TkGetScreenMMFromObj _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Window tkwin, Tcl_Obj *obj, double *doublePtr));
 EXTERN void		TkGetServerInfo _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Window tkwin));
 EXTERN void		TkGrabDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN int		TkGrabState _ANSI_ARGS_((TkWindow *winPtr));
-EXTERN TkWindow *      	TkIDToWindow _ANSI_ARGS_((Window window, 
-			    TkDisplay *display));
 EXTERN void		TkIncludePoint _ANSI_ARGS_((Tk_Item *itemPtr,
 			    double *pointPtr));
 EXTERN void		TkInitXId _ANSI_ARGS_((TkDisplay *dispPtr));
@@ -856,18 +828,12 @@ EXTERN int		TkLineToArea _ANSI_ARGS_((double end1Ptr[2],
 			    double end2Ptr[2], double rectPtr[4]));
 EXTERN double		TkLineToPoint _ANSI_ARGS_((double end1Ptr[2],
 			    double end2Ptr[2], double pointPtr[2]));
-EXTERN int		TkListAppend _ANSI_ARGS_((void **headPtrPtr,
-			    void *itemPtr, size_t size));
-EXTERN int		TkListDelete _ANSI_ARGS_((void **headPtrPtr,
-			    void *itemPtr, size_t size));
-EXTERN void *		TkListFind _ANSI_ARGS_((void *headPtr, void *itemPtr,
-			    size_t size));
 EXTERN int		TkMakeBezierCurve _ANSI_ARGS_((Tk_Canvas canvas,
 			    double *pointPtr, int numPoints, int numSteps,
 			    XPoint xPoints[], double dblPoints[]));
 EXTERN void		TkMakeBezierPostscript _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Canvas canvas, double *pointPtr,
-			    int numPoints, int numSteps));
+			    int numPoints));
 EXTERN void		TkOptionClassChanged _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkOptionDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN int		TkOvalToArea _ANSI_ARGS_((double *ovalPtr,
@@ -921,11 +887,6 @@ EXTERN double		TkPolygonToPoint _ANSI_ARGS_((double *polyPtr,
 			    int numPoints, double *pointPtr));
 EXTERN int		TkPositionInTree _ANSI_ARGS_((TkWindow *winPtr,
 			    TkWindow *treePtr));
-EXTERN int		TkPostscriptImage _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Window tkwin, Tk_PostscriptInfo psInfo,
-			    XImage *ximage, int x, int y, int width,
-			    int height));
-
 #ifndef TkpPrintWindowId
 EXTERN void		TkpPrintWindowId _ANSI_ARGS_((char *buf,
 			    Window window));
@@ -992,12 +953,6 @@ EXTERN void		TkSetRegion _ANSI_ARGS_((Display* display, GC gc,
 EXTERN void		TkSetWindowMenuBar _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Window tkwin, char *oldMenuName, 
 			    char *menuName));
-EXTERN int		TkSmoothParseProc _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, Tk_Window tkwin,
-			    CONST char *value, char *recordPtr, int offset));
-EXTERN char *		TkSmoothPrintProc _ANSI_ARGS_((ClientData clientData,
-			    Tk_Window tkwin, char *recordPtr, int offset,
-			    Tcl_FreeProc **freeProcPtr));
 EXTERN KeySym		TkStringToKeysym _ANSI_ARGS_((char *name));
 EXTERN int		TkThickPolyLineToArea _ANSI_ARGS_((double *coordPtr,
 			    int numPoints, double width, int capStyle,
@@ -1020,8 +975,6 @@ EXTERN void		TkWmRestackToplevel _ANSI_ARGS_((TkWindow *winPtr,
 			    int aboveBelow, TkWindow *otherPtr));
 EXTERN void		TkWmSetClass _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkWmUnmapWindow _ANSI_ARGS_((TkWindow *winPtr));
-EXTERN int		TkXFileProc _ANSI_ARGS_((ClientData clientData,
-			    int mask, int flags));
 
 /* 
  * Unsupported commands.
