@@ -12,7 +12,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkTrig.c 1.27 97/03/07 11:34:35
+ * RCS: @(#) $Id: tkTrig.c,v 1.2 1998/09/14 18:23:20 stanton Exp $
  */
 
 #include <stdio.h>
@@ -1066,14 +1066,6 @@ TkMakeBezierCurve(canvas, pointPtr, numPoints, numSteps, xPoints, dblPoints)
      * just put the first point into the output.
      */
 
-    if (!pointPtr) {
-	/* Of pointPtr == NULL, this function returns an upper limit.
-	 * of the array size to store the coordinates. This can be
-	 * used to allocate storage, before the actual coordinates
-	 * are calculated. */
-	return 1 + numPoints * numSteps;
-    }
-
     outputPoints = 0;
     if ((pointPtr[0] == pointPtr[numCoords-2])
 	    && (pointPtr[1] == pointPtr[numCoords-1])) {
@@ -1212,7 +1204,7 @@ TkMakeBezierCurve(canvas, pointPtr, numPoints, numSteps, xPoints, dblPoints)
  */
 
 void
-TkMakeBezierPostscript(interp, canvas, pointPtr, numPoints, numSteps)
+TkMakeBezierPostscript(interp, canvas, pointPtr, numPoints)
     Tcl_Interp *interp;			/* Interpreter in whose result the
 					 * Postscript is to be stored. */
     Tk_Canvas canvas;			/* Canvas widget for which the
@@ -1220,7 +1212,6 @@ TkMakeBezierPostscript(interp, canvas, pointPtr, numPoints, numSteps)
     double *pointPtr;			/* Array of input coordinates:  x0,
 					 * y0, x1, y1, etc.. */
     int numPoints;			/* Number of points at pointPtr. */
-    int numSteps;			/* Not used */
 {
     int closed, i;
     int numCoords = numPoints*2;
