@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkMacXStubs.c 1.87 97/11/20 18:35:29
+ * RCS: @(#) $Id: tkMacXStubs.c,v 1.3 1998/09/14 18:23:40 stanton Exp $
  */
 
 #include "tkInt.h"
@@ -462,45 +462,6 @@ XSendEvent(
     return 0;
 }
 
-void
-XClearWindow(display, w)
-    Display* display;
-    Window w;
-{
-}
-
-void
-XWarpPointer(display, src_w, dest_w, src_x, src_y, src_width,
-	src_height, dest_x, dest_y)
-    Display* display;
-    Window src_w;
-    Window dest_w;
-    int src_x;
-    int src_y;
-    unsigned int src_width;
-    unsigned int src_height;
-    int dest_x;
-    int dest_y;
-{
-}
-
-void
-XQueryColor(display, colormap, def_in_out)
-    Display* display;
-    Colormap colormap;
-    XColor* def_in_out;
-{
-}
-
-void
-XQueryColors(display, colormap, defs_in_out, ncolors)
-    Display* display;
-    Colormap colormap;
-    XColor* defs_in_out;
-    int ncolors;
-{
-}
-
 int
 XGetWindowProperty(
     Display *display,
