@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkWinInt.h 1.34 97/09/02 13:06:20
+ * RCS: @(#) $Id: tkWinInt.h,v 1.3 1999/02/04 21:01:35 stanton Exp $
  */
 
 #ifndef _TKWININT
@@ -36,7 +36,7 @@
 #define WS_EX_TOOLWINDOW	0x00000080L 
 #endif
 
-/*typedef struct TkFontAttributes TkFontAttributes;*/
+typedef struct TkFontAttributes TkFontAttributes;
 
 /*
  * The TkWinDCState is used to save the state of a device context
@@ -146,6 +146,7 @@ extern int tkpWinRopModes[];
  * Internal procedures used by more than one source file.
  */
 
+extern void		TkWinCancelMouseTimer _ANSI_ARGS_((void));
 extern LRESULT CALLBACK	TkWinChildProc _ANSI_ARGS_((HWND hwnd, UINT message,
 			    WPARAM wParam, LPARAM lParam));
 extern void		TkWinClipboardRender _ANSI_ARGS_((TkDisplay *dispPtr,
